@@ -1,26 +1,27 @@
 from pydantic import BaseSettings, Field
 from nonebot import get_driver
-from typing import List, Optional
-
+from nonebot.log import logger
 from nonebot.rule import to_me
-from pathlib import Path
+
 
 class Config(BaseSettings):
     # Your Config Here
     # gpt3_api_key_path: str = "config/chatgpt_api_key.yml"
     openai_api_key: str = ''
     gpt3_command_prefix: str = 'gpt3'
+    gpt3_default_preset: str = ''
     gpt3_need_at: bool = False
     gpt3_image_render: bool = False
     gpt3_image_limit: int = 200
     gpt3_max_tokens: int = 1000
-    gpt3_model : str = 'gpt-3.5-turbo'
+    gpt3_model: str = 'gpt-3.5-turbo'
     gpt3_chat_count_per_day: int = 200
-
+    gpt3_proxy: str = ''
 
     class Config:
         extra = "ignore"
 
+
 driver = get_driver()
 global_config = driver.config
 config = Config.parse_obj(global_config)
@@ -33,15 +34,18 @@ gpt3_image_render = config.gpt3_image_render
 gpt3_image_limit = config.gpt3_image_limit
 gpt3_max_tokens = config.gpt3_max_tokens
 gpt3_model = config.gpt3_model
-# gpt3_api_key_list_from_env = config.gpt3_api_key_list_from_env
+gpt3_default_preset = config.gpt3_default_preset
+gpt3_proxy = config.gpt3_proxy
 gpt3_chat_count_per_day = config.gpt3_chat_count_per_day
 
 
-from nonebot.log import logger
+
 if openai_api_key:
     logger.info(f"加载api keys: {openai_api_key}")
 else:
     logger.warning('没有配置api key')
+logger.info(f"加载代理: {gpt3_proxy if gpt3_proxy else '无'}")
+logger.info(f"加载默认人格: {gpt3_default_preset}")
 
 # 基本会话
 matcher_params = {}
